# -*- coding: utf-8 -*-
""" File Input/Output Utility Methods """


import os
import traceback
from datetime import datetime

from io import StringIO
from io import open as io_open

from csv import reader as csv_reader
from typing import List
from typing import Optional

from sys import platform
from pathlib import Path
from collections import defaultdict
from codecs import open as codecs_open

from json import load as json_load
from json import loads as json_loads
from json import dumps as json_dumps
from json.decoder import JSONDecodeError

from yaml import Loader
from yaml import YAMLError
from yaml import dump as yaml_dump
from yaml import load as yaml_load


class FileIO(object):
    """ File Input/Output Utility Methods """

    

    @staticmethod
    def is_empty_folder(folder_name: str) -> bool:
        
        """ Check if a Folder is Empty of Contents

        Args:
            folder_name (str): a fully qualified path to a folder

        Returns:
            bool: True if the folder has no contents
        """
        if FileIO.exists(folder_name):
            if len(os.listdir(folder_name)):
                return False
        return True

    @staticmethod
    def local_directory() -> str:
        """ Retrieve a Platform Specific Local Directory

        Raises:
            NotImplementedError: Platform O/S Not Recognized

        Returns:
            str: absolute Path to a Local Directory
        """
        if platform == 'linux' or platform == 'linux2':
            return os.environ['HOME']
        elif platform == 'darwin':
            return os.environ['HOME']
        elif platform == 'win32':
            return os.environ['APPDATA']
        raise NotImplementedError(platform)

    @staticmethod
    def local_directory_by_name(folder_name: str) -> str:
        """ Create a Local Directory under a Platform Specific Directory

        Args:
            folder_name (str): the local directory to create

        Returns:
            str: absolute Path to Local Directory
        """
        local_path = FileIO.join(FileIO.local_directory(), folder_name)
        FileIO.exists_or_create(local_path)
        return local_path

    @staticmethod
    def normpath(path: str) -> str:
        """ Normalize Path to use forward slashes

        This differs from
            os.path.normpath
        in that the Python std lib call will normalize on a platform-specific basis

        This means a path like this
            alpha/bravo/charlie
        will become
            alpha\\bravo\\charlie
        on a Windows platform; which is silly, because forward slashes work just fine on Windows

        Args:
            path (str): the incoming path

        Returns:
            str: the outgoing path
        """
        if '\\' in path:
            path = path.replace('\\', '/')
            os.path.normpath
        return path

    @staticmethod
    def join(*args) -> str:
        return os.path.normpath(os.path.join(*args))

    @staticmethod
    def join_cwd(*args) -> str:
        return os.path.normpath(os.path.join(os.getcwd(), *args))

    @staticmethod
    def temp(data: object,
             file_name: Optional[str] = None,
             raise_exception: bool = False,
             print_output_path: bool = True) -> str:
        """ Write a Data Object to a Temp File

        Args:
            data (object): any data object
            file_name (Optional[str]): an optional file name
            raise_exception (bool): act as a program breakpoint.  Default is False.
            print_output_path (bool): print output file path to console.  Default is True.

        Raises:
            NotImplementedError: unrecognized data type
            ValueError: unrecognized data type

        Returns:
            str: the path the file was written to
        """

        _type = type(data)
        if _type not in [dict, list, str]:
            raise NotImplementedError(_type)

        def get_filename() -> str:
            if not file_name or not len(file_name):
                return 'temp.json'
            return file_name

        path = FileIO.join(FileIO.local_directory(), get_filename())

        basename = os.path.basename(path)
        if not os.path.exists(basename):
            if print_output_path:
                print(f'Created Output Path: {basename}')
            FileIO.create_dir(basename)

        if _type == str:
            FileIO.write_string(data, path)
        else:
            FileIO.write_json(data, path)

        if raise_exception:
            raise Exception(f'FileIO Breakpoint: {path}')

        if print_output_path:
            print(f'Wrote File to {path}')

        return path

    @staticmethod
    def exists(file_path: str) -> bool:
        """ Check if File or Directory exists

        Args:
            file_path (str): a file path

        Returns:
            bool: True if file or directory exists
        """
        return os.path.exists(file_path)

    @staticmethod
    def exists_or_error(file_path: str) -> None:
        """ Raise Exception if File Path does not exist

        Args:
            file_path (str): an input path

        Raises:
            FileNotFoundError: an input path
        """
        if not FileIO.exists(file_path):
            raise FileNotFoundError(file_path)

    @staticmethod
    def exists_or_create(file_path: str) -> None:
        """ Create File Path if File Path does not exist

        Args:
            file_path (str): an input path
        """
        if not FileIO.exists(file_path):
            FileIO.create_dir(file_path)

    @staticmethod
    def create_dir(dir_name: str) -> None:
        """ Create Directory (recursive)

        Args:
            dir_name (str): an input path
        """
        if not os.path.isdir(dir_name):
            os.makedirs(dir_name)

    @staticmethod
    def get_file_name(file_path: str) -> str:
        """ Get the File Name From the File Path

        Args:
            file_path (str): the path to the file
                example: /root/temp-file.ext

        Returns:
            str: the filename only
                example: temp-file
        """
        file_name = os.path.basename(file_path)
        return os.path.splitext(file_name)[0]

    @staticmethod
    def debug(data: object) -> None:
        """ Debug Mechanism for Examining 'Stack Trace'

        Args:
            data (object): the JSON object

        Raises:
            ValueError: Stops Program Execution
        """
        file_path = os.path.join(os.environ['DESKTOP'], 'temp.json')
        FileIO.write_json(data, file_path=file_path)
        raise ValueError(f'Wrote Temp File: {file_path}')

    @staticmethod
    def write_image(data: object,
                    file_path: str,
                    debug: bool = False) -> None:
        """ Write an Image to File

        Args:
            data (object): the image
            file_path (str): the absolute and qualified output file path
            debug (bool). if True, print result to console. Defaults to False.
        """
        with open(file_path, 'wb') as f:
            f.write(data)
            if debug:
                print(f'Wrote to File: {file_path}')

    @staticmethod
    def write_json(data: object,
                   file_path: str,
                   debug: bool = False) -> None:
        """ Write JSON to File

        Args:
            data (object): the JSON object
            file_path (str): the absolute and qualified output file path
            debug (bool). if True, print result to console. Defaults to False.
        """
        with io_open(file_path, 'w') as json_file:
            json_dump = json_dumps(data,
                                   indent=4,
                                   sort_keys=False,
                                   ensure_ascii=True)
            json_file.write(json_dump)

            if debug:
                print(f'Wrote to File: {file_path}')

    @staticmethod
    def read_json(file_path: str) -> object:
        """ Read JSON from File

        Args:
            file_path (str): the absolute and qualified output file path
            file_encoding (str, optional): The output file encoding. Defaults to "utf-8".

        Returns:
            [type]: the JSON object
        """
        with open(file_path) as json_file:
            return json_load(json_file)

    @staticmethod
    def read_string(file_path: str,
                    encoding: str = 'utf-8',
                    replace_newlines: bool = False) -> str:
        """ Read String from File

        Args:
            file_path (str): the absolute and qualified input file path
            encoding (str, optional): the file encoding. Defaults to "utf-8".

        Returns:
            str: the file contents as a single string
        """
        with open(file_path, 'r', encoding=encoding) as myfile:
            if replace_newlines:
                return myfile.read().replace('\n', ' ')
            return myfile.read()

    @staticmethod
    def write_string(input_text: str,
                     file_path: str,
                     file_encoding: str = 'utf-8',
                     debug: bool = False) -> None:
        """ Write String to File

        Args:
            input_text (str): the string contents to write to file
            file_path (str): the absolute and qualified input file path
            file_encoding (str, optional): the file encoding. Defaults to "utf-8".
            debug (bool). if True, print result to console. Defaults to False.

        Raises:
            ValueError: Invalid Input
        """
        if not input_text or type(input_text) != str:
            raise ValueError

        target = codecs_open(file_path,
                             mode='w',
                             encoding=file_encoding)

        target.write(input_text)
        target.close()

        if debug:
            print(f'Wrote to File: {file_path}')

    @staticmethod
    def write_lines(lines: list,
                    file_path: str,
                    file_encoding: str = 'utf-8',
                    debug: bool = False) -> None:
        """ Write Lines to File

        Args:
            lines (list): the list to write to file
            file_path (str): the absolute and qualified input file path
            file_encoding (str, optional): the file encoding. Defaults to "utf-8".
            debug (bool). if True, print result to console. Defaults to False.

        Raises:
            ValueError: Invalid Input
            NotImplementedError: Input is neither a List nor Str
        """

        def get_input_text() -> str:
            _type = type(lines)
            if _type == list:
                return '\n'.join(lines)
            if _type == str:
                return str(lines)
            raise NotImplementedError(_type)

        FileIO.write_string(input_text=get_input_text(),
                            file_path=file_path,
                            file_encoding=file_encoding,
                            debug=debug)

    @staticmethod
    def write_yaml(d: dict,
                   file_path: str,
                   debug: bool = False) -> None:
        """ Write YAML to File

        Args:
            d (dict): the py YAML dictionary
            file_path (str): the absolute and qualified output file path
            debug (bool). if True, print result to console. Defaults to False.
        """
        with open(file_path, 'w') as file:
            yaml_dump(d, file)
            if debug:
                print(f'Wrote to File: {file_path}')

    @staticmethod
    def read_yaml(file_path: str) -> dict:
        """ Read YAML from File

        Args:
            file_path (str): the absolute and qualified input file path

        Raises:
            ValueError: the file is not valid YAML

        Returns:
            dict: a py YAML dictionary
        """
        FileIO.exists_or_error(file_path)

        with open(file_path, 'r', encoding='utf-8') as stream:
            try:

                return yaml_load(stream, Loader=Loader)

            except YAMLError:
                traceback.format_exc()
                raise ValueError('\n'.join([
                    'Invalid File',
                    '\t{0}'.format(file_path)]))

            except UnicodeDecodeError:
                print(traceback.format_exc())
                raise ValueError('\n'.join([
                    'Encoding Error',
                    '\t{0}'.format(file_path)]))

    @staticmethod
    def read_lines(file_path: str,
                   file_encoding: str = 'utf-8') -> list:
        """ Read Lines of a File into a List

        Args:
            file_path (str): the absolute and qualified input file path
            file_encoding (str, optional): the file encoding. Defaults to "utf-8".

        Returns:
            list: each line in the file as a list
        """
        target = codecs_open(file_path,
                             mode='r',
                             encoding=file_encoding)
        lines = [x.replace('\n', '').strip() for x in target.readlines() if x]
        target.close()

        return lines

    @staticmethod
    def yield_lines(file_path: str,
                    file_encoding: str = 'utf-8') -> list:
        """Read Lines of a File using a yield Generator

        Args:
            file_path (str): the absolute and qualified input file path
            file_encoding (str, optional): the file encoding. Defaults to "utf-8".

        Returns:
            Generator: a yield function
            Sample Output:
                ['A3.26\t1993\t2\t2']
                ['A3.26\t1994\t2\t2']
                ['A3.26\t1995\t6\t6']
                ['A3.26\t1996\t4\t4']
                ['A3.26\t1997\t5\t5']
                ['A3.26\t1998\t1\t1']
                ['A3.26\t1999\t4\t3']

            Notes:
                each output line is a list with one element that requires independent delimitation
        """
        with codecs_open(file_path, mode='r', encoding=file_encoding) as f:
            for line in csv_reader(f):
                yield line

    @staticmethod
    def has_files(directory: str,
                  extension: str) -> bool:
        """ Check if files exist in a directory by extension

        Args:
            file_path (str): the absolute and qualified directory path
            extension (str): the extendion to check for

        Returns:
            bool: True if files exist
        """
        return len(FileIO.load_files(directory, extension))

    @staticmethod
    def delete_files(directory: str,
                     extension: str,
                     limit: int = None,
                     blacklist: list = None,
                     recursive: bool = False) -> list:
        """ Delete Files from a directory

        Args:
            directory (str): the absolute and qualified directory path
            extension (str): the file extension to delete
            recursive (bool, optional): deletes files recursively if set to True. Defaults to False.
            limit (int, optional): The number of files to deletes. Defaults to None.
            blacklist (list, optional): an list of File Names to exclude. Defaults to None.

        Returns:
            list: list of files deleted
        """
        files = FileIO.load_files(directory=directory,
                                  extension=extension,
                                  limit=limit,
                                  blacklist=blacklist,
                                  recursive=recursive)

        [os.remove(x) for x in files]

        return files

    @staticmethod
    def count_files(directory: str,
                    extension: str,
                    recursive: bool = False) -> Optional[int]:
        """ Count Files in a directory

        Args:
            directory (str): the absolute and qualified directory path
            extension (str): the file extension to load
            recursive (bool, optional): loads files recursively if set to True. Defaults to False.

        Returns:
            Optional[int]: the total files (0..*)
                if the directory does not exist, return None
        """
        if not FileIO.exists(directory):
            return None

        return len(FileIO.load_files(directory=directory,
                                     extension=extension,
                                     limit=None,
                                     blacklist=None,
                                     recursive=recursive))

    @staticmethod
    def list_directory(directory: str,
                       recursive: bool = True) -> list:
        """ Load Files from a directory

        Args:
            directory (str): the absolute and qualified directory path
            recursive (bool, optional): loads files recursively if set to True. Defaults to True.

        Returns:
            list: list of files
        """
        return FileIO.load_files(directory=directory,
                                 extension=None,
                                 limit=None,
                                 blacklist=None,
                                 recursive=recursive)

    @staticmethod
    def load_files(directory: str,
                   extension: Optional[str] = None,
                   limit: Optional[int] = None,
                   blacklist: Optional[List[str]] = None,
                   recursive: bool = False) -> list:
        """ Load Files from a directory

        Args:
            directory (str): the absolute and qualified directory path
            extension (Optional[str], optional): the file extension to load. Defaults to None.
            limit (Optional[int], optional): The number of files to load. Defaults to None.
            blacklist (Optional[List[str]], optional): an list of File Names to exclude. Defaults to None.
            recursive (bool, optional): loads files recursively if set to True. Defaults to False.

        Returns:
            list: list of files
        """
        def non_recursive_loader() -> list:
            files = os.listdir(directory)

            if extension:
                files = [f for f in files if f.endswith(extension)]

            if limit and len(files) >= limit:
                files = files[:limit]

            files = [
                os.path.normpath(os.path.join(directory, f))
                for f in files
            ]

            return files

        def recursive_loader() -> list:
            results = []

            for dirpath, _, files in os.walk(directory):

                if extension:
                    files = [
                        x for x in files
                        if x.lower().endswith(extension)
                    ]

                for name in files:

                    path = os.path.join(dirpath, name)
                    if not is_valid(path):
                        continue

                    results.append(path)
                    if limit and len(results) >= limit:
                        return results

            return results

        def load_files() -> list:
            if recursive:
                return recursive_loader()
            return non_recursive_loader()

        def is_valid(a_file: str) -> bool:
            if blacklist and len(blacklist):
                for entry in blacklist:
                    if entry in a_file:
                        return False
            return True

        return [x for x in load_files() if is_valid(x)]

    @staticmethod
    def load_all_files(directory: str,
                       exclude: list = None) -> list:
        """ Load all Files from a directory and key by extension

        Args:
            directory (str): the absolute and qualified directory path
            exclude (list): a list of folders (or sub-folders) to exclude

        Returns:
            list: list of files
        """

        d = defaultdict(list)

        # e.g., '.git'
        if not exclude:
            exclude = []

        # e.g., '/.git/'
        exclude_sub = []
        for sub_folder in exclude:
            if os.path.sep not in sub_folder:
                exclude_sub.append(f'{os.path.sep}{sub_folder}{os.path.sep}')
            else:
                exclude_sub.append(sub_folder)

        def load_files() -> list:
            results = []

            for dirpath, _, files in os.walk(directory):

                # e.g., exclude '/a/b/c/.git'
                if os.path.basename(dirpath) in exclude:
                    continue

                # e.g., exclude '/a/b/c/.git/d/e'
                def has_excluded_subfolder() -> bool:
                    for sub_folder in exclude_sub:
                        if sub_folder in dirpath:
                            return True
                    return False

                if has_excluded_subfolder():
                    continue

                for name in files:
                    results.append(os.path.normpath(
                        os.path.join(dirpath, name)))

            return results

        for f in load_files():
            d[FileIO.extension(f)].append(f)

        return dict(d)

    @staticmethod
    def load_all_folders(directory: str,
                         exclude: list = None) -> list:
        """ Load all Folders from a directory

        Args:
            directory (str): the absolute and qualified directory path
            exclude (list): a list of folders (or sub-folders) to exclude

        Returns:
            list: list of folder base names
        """

        d_folders = defaultdict(list)

        # e.g., '.git'
        if not exclude:
            exclude = []

        # e.g., '/.git/'
        exclude_sub = []
        for sub_folder in exclude:
            if os.path.sep not in sub_folder:
                exclude_sub.append(f'{os.path.sep}{sub_folder}{os.path.sep}')
            else:
                exclude_sub.append(sub_folder)

        for dirpath, _, files in os.walk(directory):
            base_name = os.path.basename(dirpath)

            # e.g., exclude '/a/b/c/.git'
            if base_name in exclude:
                continue

            # e.g., exclude '/a/b/c/.git/d/e'
            def has_excluded_subfolder() -> bool:
                for sub_folder in exclude_sub:
                    if sub_folder in dirpath:
                        return True
                return False

            if has_excluded_subfolder():
                continue

            for name in files:
                d_folders[base_name].append(os.path.normpath(
                    os.path.join(dirpath, name)))

        return dict(d_folders)

    def extension(file_name: str) -> str or None:
        """ Extract Extension from a File Name

        Args:
            file_name (str): a file name

        Returns:
            str: the file extension
        """
        ext = Path(file_name).suffix
        if ext.startswith('.'):
            return ext[1:]
        if not len(ext):
            return None
        return ext

    @staticmethod
    def parse_yaml(file_data: str) -> dict:
        """ Read YAML from String

        Args:
            file_data (str): the string-ified YAML data

        Raises:
            ValueError: the file data is not valid YAML

        Returns:
            dict: a py YAML dictionary
        """
        try:
            return yaml_load(StringIO(file_data), Loader)
        except YAMLError:
            raise ValueError('Invalid YAML Data')

    @staticmethod
    def parse_json(file_data: str) -> dict:
        """ Read JSON from String

        Args:
            file_data (str): the string-ified JSON data

        Raises:
            ValueError: the file data is not valid JSON

        Returns:
            dict: a py JSON dictionary
        """
        try:
            file_data_type = type(file_data)
            if file_data_type == dict:
                return dict(file_data)
            if file_data_type == list:
                return list(file_data)

            return json_loads(file_data)

        except JSONDecodeError:
            raise ValueError('Invalid JSON Data')

    @staticmethod
    def event(data: object,
              local_directory_name: str,
              file_name: str) -> None:
        """ Persist an Event to a Local Directory

        Args:
            data (object): the JSON data (typically a list or dict)
            local_directory_name (str): the relative path 
            file_name (str): the output file name
        """

        local_directory_path = FileIO.local_directory_by_name(
            local_directory_name)

        ts = str(datetime.now().timestamp())

        absolute_path = FileIO.join(
            local_directory_path,
            f'{file_name}-{ts}.json')

        FileIO.write_json(data=data,
                          file_path=absolute_path,
                          debug=True)




#!/usr/bin/env python
# -*- coding: UTF-8 -*-

d_abbreviations = {
    'approx.': 'approximately',
    'appt.': 'appointment',
    'apt.': 'apartment',
    'ave.': 'avenue',
    'adj.': 'adjective',
    'adm.': 'administration',
    'abbr.': 'abbreviation',
    'abr.': 'abridged',
    'aka.': 'aka',
    'acad.': 'academic',
    'assoc.': 'association',
    'blvd.': 'boulevard',
    'biol.': 'biology',
    'bibliog.': 'bibliography',
    'bot.': 'botany',
    'cyn.': 'canyon',
    'cp.': 'compare',
    'cap.': 'capital',
    'chap.': 'chapter',
    'chem.': 'chemical',
    'co.': 'company',
    'colloq.': 'colloquial',
    'conf.': 'conference',
    'cont.': 'containing',
    'com.': 'commercial',
    'cr.': 'credit',
    'crit.': 'criticism',
    'dept.': 'department',
    'dr.': 'dr~~',
    'diff.': 'different',
    'def.': 'definition',
    'est.': 'established',
    'ea.': 'each',
    'e.g.': 'example',
    'etc.': 'etc',
    'gen.': 'general',
    'impt.': 'important',
    'ln.': 'lane',
    'mr.': 'mr~~',
    'min.': 'minute',
    'misc.': 'miscellaneous',
    'mrs.': 'mrs~~',
    'no.': 'number',
    'nec.': 'necessary',
    'rd.': 'road',
    're.': 'regarding',
    'st.': 'street',
    'sim.': 'similar',
    'tel.': 'telephone',
    'temp.': 'temp',
    'vet.': 'vet',
    'vs.': 'versus'
}



# !/usr/bin/env python
# -*- coding: UTF-8 -*-
""" API for spaCy Core Functionality """


from spacy.lang.en import English

from lingpatlab.baseblock import (
    BaseObject,
    Stopwatch,
    Enforcer
)

from lingpatlab.tokenizer.bp import Tokenizer
from lingpatlab.parser.svc import ParseInputTokens

from lingpatlab.analyze.bp import (
    ExtractTopics,
    ExtractPeople
)

from lingpatlab.utils.dto import (
    Sentence,
    Sentences
)


class LingPatLab(BaseObject):
    """
    Provides an API interface for core functionalities of a spaCy-based NLP pipeline, including tokenization,
    parsing, phrase extraction, and summarization of input text.

    This API orchestrates the workflow from raw text to structured data representations suitable for further NLP tasks.
    """

    __tokenize = None
    __parse = None
    __topics = None
    __people = None
    __summarize = None

    def __init__(self):
        """
        Initializes the SpacyCoreAPI by setting up the base object and preparing internal components for NLP tasks.

        Created:
            27-Feb-2024
            craigtrim@gmail.com
            *   https://github.com/craigtrim/datapipe-apis/issues/43
        Updated:
            19-Mar-2024
            craigtrim@gmail.com
            *   https://github.com/craigtrim/datapipe-apis/issues/61
        """
        BaseObject.__init__(self, __name__)

    def extract_people(self,
                       sentences: Sentence | Sentences) -> list[str]:
        """
        Extracts people from the given sentences.

        Args:
            sentences (Union[Sentence, Sentences]): The input sentences from which to extract people.

        Returns:
            List[str]: A list of extracted people names.

        Raises:
            TypeError: If the input sentences are not of type Sentence or Sentences.
        """
        if not self.__people:
            self.__people = ExtractPeople().process

        if type(sentences) == Sentence:
            sentences = Sentences([sentences])

        if not type(sentences) == Sentences:
            raise TypeError(type(sentences))

        return self.__people(sentences=sentences)

    def extract_topics(self,
                       sentences: Sentence | Sentences = None) -> list[str]:
        """
        Extracts phrases from the given structured Sentences object, which is a collection of parsed sentences.

        Parameters:
            sentences (Union[Sentence, Sentences]): A structured collection of sentences to extract phrases from.

        Returns:
            List[str]: A list of extracted phrases.
        """
        if not self.__topics:
            self.__topics = ExtractTopics().process

        if type(sentences) == Sentence:
            sentences = Sentences([sentences])

        if not type(sentences) == Sentences:
            raise TypeError(type(sentences))

        return self.__topics(sentences=sentences)

    def parse_input_text(self,
                         input_text: str,
                         en_spacy_model: English | None = None) -> Sentence:
        """
        Parses the given input text into a structured Sentence object, encapsulating the parsed tokens and their relations.

        Parameters:
            input_text (str): The text to parse.

        Returns:
            Sentence: A structured representation of the parsed sentence.

        Raises:
            TypeError: If the input_text is not a string.
        """
        if not isinstance(input_text, str):
            raise TypeError(type(input_text))

        sw = Stopwatch()

        if not self.__tokenize:
            self.__tokenize = Tokenizer().input_text

        if not self.__parse:
            self.__parse = ParseInputTokens(en_spacy_model).process

        input_tokens: list[str] = self.__tokenize(input_text)
        parse_results: Sentence = self.__parse(input_tokens)

        if self.isEnabledForDebug:
            self.logger.debug(
                f"Parse Completed (total-results = {parse_results.size()}), (total-time = {str(sw)})")

        return parse_results

    def parse_input_lines(self,
                          input_lines: list[str],
                          en_spacy_model: English | None = None) -> Sentences:
        """
        Parses a list of input lines (strings), each into a Sentence object, and returns them as a Sentences object.

        This function is ideal for parsing multiple sentences or lines of text, providing a structured representation for each.

        Parameters:
            input_lines (List[str]): A list of strings, each representing a line of text to parse.

        Returns:
            Sentences: A collection of Sentence objects parsed from the input lines.

        Raises:
            TypeError: If the input_lines is not a list of strings.
        """
        if not isinstance(input_lines, list):
            raise TypeError(type(input_lines))

        sentences = []

        for input_text in input_lines:
            sentences.append(self.parse_input_text(
                input_text=input_text,
                en_spacy_model=en_spacy_model
            ))

        return Sentences(sentences)



from .bp import *
from .svc import *
from .dmo import *
from .dto import *

from .svc.find_wordnet import FindWordnet
from .os import *


def is_wordnet_term(input_text: str) -> bool:
    return FindWordnet().exists(input_text)




#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_i_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.171458'}

wordnet_terms_i = [
    'ia',
    'iaa',
    'iaea',
    'iago',
    'iamb',
    'iambic',
    'iambs',
    'iambus',
    'ian',
    'ianfu',
    'iapetus',
    'iatrogenic',
    'ibadan',
    'iberia',
    'iberian',
    'iberis',
    'ibert',
    'ibex',
    'ibis',
    'ibises',
    'ibm',
    'ibrahim',
    'ibrd',
    'ibsen',
    'ibsenian',
    'ibuprofen',
    'ic',
    'icaco',
    'icao',
    'icarus',
    'icbm',
    'icc',
    'ice',
    'iceberg',
    'icebergs',
    'iceboat',
    'icebound',
    'icebox',
    'icebreaker',
    'icecap',
    'icecream',
    'iced',
    'icefall',
    'icehouse',
    'iceland',
    'icelander',
    'icelandic',
    'iceman',
    'icepick',
    'icetray',
    'ichneumon',
    'ichneumonidae',
    'ichor',
    'ichorous',
    'ichthyolatry',
    'ichthyologist',
    'ichthyology',
    'ichthyosaur',
    'ichthyosauria',
    'ichthyosauridae',
    'ichthyosaurs',
    'ichthyosaurus',
    'ichthyosis',
    'ichyostega',
    'icicle',
    'iciness',
    'icing',
    'icings',
    'icky',
    'icon',
    'iconic',
    'iconoclasm',
    'iconoclast',
    'iconoclastic',
    'iconography',
    'iconolatry',
    'iconology',
    'iconoscope',
    'icons',
    'icosahedral',
    'icosahedron',
    'icsh',
    'ictal',
    'ictalurus',
    'icteria',
    'icteric',
    'icteridae',
    'icterogenic',
    'icterus',
    'ictic',
    'ictiobus',
    'ictodosaur',
    'ictodosauria',
    'ictonyx',
    'ictus',
    'icu',
    'icy',
    'id',
    'ida',
    'idaho',
    'idahoan',
    'iddm',
    'idea',
    'ideal',
    'idealisation',
    'idealise',
    'idealised',
    'idealism',
    'idealist',
    'idealistic',
    'ideality',
    'idealization',
    'idealize',
    'idealized',
    'idealizes',
    'idealizing',
    'ideally',
    'idealogue',
    'ideals',
    'ideas',
    'ideate',
    'ideation',
    'ideational',
    'idempotent',
    'identical',
    'identically',
    'identicalness',
    'identifiable',
    'identification',
    'identified',
    'identifier',
    'identifies',
    'identify',
    'identifying',
    'identikit',
    'identities',
    'identity',
    'ideogram',
    'ideograms',
    'ideograph',
    'ideographic',
    'ideography',
    'ideologic',
    'ideological',
    'ideologies',
    'ideologist',
    'ideologue',
    'ideology',
    'ides',
    'idesia',
    'idf',
    'idiocy',
    'idiographic',
    'idiolatry',
    'idiolect',
    'idiom',
    'idiomatic',
    'idiomatical',
    'idiopathic',
    'idiopathy',
    'idiosyncrasy',
    'idiosyncratic',
    'idiot',
    'idiotic',
    'iditarod',
    'idle',
    'idleness',
    'idler',
    'idles',
    'idling',
    'idly',
    'ido',
    'idocrase',
    'idol',
    'idolater',
    'idolatress',
    'idolatrous',
    'idolatry',
    'idolisation',
    'idolise',
    'idolised',
    'idoliser',
    'idolization',
    'idolize',
    'idolized',
    'idolizer',
    'idolizes',
    'idols',
    'idp',
    'idun',
    'idwal',
    'idyl',
    'idyll',
    'idyllic',
    'idyllically',
    'ie',
    'ied',
    'if',
    'ifc',
    'iffy',
    'ig',
    'iga',
    'igbo',
    'igd',
    'ige',
    'igg',
    'igigi',
    'iglesias',
    'igloo',
    'iglu',
    'igm',
    'ignatius',
    'igneous',
    'ignescent',
    'ignitable',
    'ignite',
    'ignited',
    'igniter',
    'ignites',
    'ignitible',
    'igniting',
    'ignition',
    'ignitor',
    'ignobility',
    'ignoble',
    'ignobleness',
    'ignobly',
    'ignominious',
    'ignominiousness',
    'ignominy',
    'ignoramus',
    'ignorance',
    'ignorant',
    'ignorantness',
    'ignore',
    'ignored',
    'ignores',
    'ignoring',
    'iguana',
    'iguanas',
    'iguania',
    'iguanid',
    'iguanidae',
    'iguanodon',
    'iguanodons',
    'iguanodontidae',
    'iguassu',
    'iguazu',
    'ii',
    'iii',
    'iis',
    'ijssel',
    'ijsselmeer',
    'ijtihad',
    'ike',
    'ikhanaton',
    'ikon',
    'il',
    'ilama',
    'ileitis',
    'ileocolic',
    'ileostomy',
    'ileum',
    'ileus',
    'ilex',
    'iliac',
    'iliad',
    'iliamna',
    'ilion',
    'ilium',
    'ilk',
    'ill',
    'illampu',
    'illation',
    'illative',
    'illecebrum',
    'illegal',
    'illegalise',
    'illegality',
    'illegalize',
    'illegally',
    'illegibility',
    'illegible',
    'illegitimacy',
    'illegitimate',
    'illiberal',
    'illiberality',
    'illicit',
    'illicitly',
    'illicitness',
    'illicium',
    'illimani',
    'illimitable',
    'illinois',
    'illinoisan',
    'illiteracy',
    'illiterate',
    'illness',
    'illnesses',
    'illogic',
    'illogical',
    'illogicality',
    'illogicalness',
    'ills',
    'illume',
    'illuminance',
    'illuminant',
    'illuminate',
    'illuminated',
    'illuminating',
    'illumination',
    'illumine',
    'illusion',
    'illusional',
    'illusionary',
    'illusionist',
    'illusions',
    'illusive',
    'illusory',
    'illustrate',
    'illustrated',
    'illustrates',
    'illustrating',
    'illustration',
    'illustrations',
    'illustrative',
    'illustrator',
    'illustrious',
    'illustriousness',
    'illyria',
    'illyrian',
    'ilmen',
    'ilmenite',
    'ilo',
    'ilosone',
    'ilx',
    'ilxx',
    'ilxxx',
    'image',
    'imagery',
    'images',
    'imaginable',
    'imaginary',
    'imagination',
    'imaginative',
    'imaginativeness',
    'imagine',
    'imagined',
    'imaging',
    'imagism',
    'imago',
    'imam',
    'imaret',
    'imaum',
    'imavate',
    'imbalance',
    'imbalanced',
    'imbauba',
    'imbecile',
    'imbecilic',
    'imbecility',
    'imbed',
    'imbibe',
    'imbiber',
    'imbibing',
    'imbibition',
    'imbricate',
    'imbricated',
    'imbrication',
    'imbroglio',
    'imbrue',
    'imbue',
    'imbued',
    'imf',
    'imidazole',
    'imide',
    'iminazole',
    'imipramine',
    'imitate',
    'imitated',
    'imitates',
    'imitating',
    'imitation',
    'imitations',
    'imitative',
    'imitator',
    'immaculate',
    'immaculately',
    'immaculateness',
    'immanence',
    'immanency',
    'immanent',
    'immanuel',
    'immaterial',
    'immaterialise',
    'immateriality',
    'immaterialize',
    'immature',
    'immatureness',
    'immaturity',
    'immeasurable',
    'immeasurably',
    'immediacy',
    'immediate',
    'immediately',
    'immediateness',
    'immense',
    'immensely',
    'immenseness',
    'immensity',
    'immensurable',
    'immerse',
    'immersed',
    'immersing',
    'immersion',
    'immigrant',
    'immigrants',
    'immigrate',
    'immigrated',
    'immigration',
    'imminence',
    'imminency',
    'imminent',
    'imminentness',
    'immingle',
    'immiscible',
    'immix',
    'immobile',
    'immobilisation',
    'immobilise',
    'immobility',
    'immobilization',
    'immobilize',
    'immobilized',
    'immobilizes',
    'immobilizing',
    'immoderate',
    'immoderately',
    'immoderateness',
    'immoderation',
    'immodest',
    'immodesty',
    'immolate',
    'immolated',
    'immolation',
    'immoral',
    'immorality',
    'immortal',
    'immortalise',
    'immortality',
    'immortalize',
    'immortalized',
    'immortals',
    'immortelle',
    'immotile',
    'immotility',
    'immovability',
    'immovable',
    'immovableness',
    'immovably',
    'immoveable',
    'immune',
    'immunisation',
    'immunise',
    'immunised',
    'immunity',
    'immunization',
    'immunize',
    'immunized',
    'immunoassay',
    'immunochemical',
    'immunochemistry',
    'immunocompetence',
    'immunocompetent',
    'immunocompromised',
    'immunodeficiency',
    'immunodeficient',
    'immunoelectrophoresis',
    'immunofluorescence',
    'immunogen',
    'immunogenic',
    'immunogenicity',
    'immunoglobulin',
    'immunoglobulins',
    'immunohistochemistry',
    'immunologic',
    'immunological',
    'immunologically',
    'immunologist',
    'immunology',
    'immunopathology',
    'immunosuppressant',
    'immunosuppressed',
    'immunosuppression',
    'immunosuppressive',
    'immunosuppressor',
    'immunotherapeutic',
    'immunotherapy',
    'immure',
    'immurement',
    'immutability',
    'immutable',
    'immutableness',
    'imo',
    'imp',
    'impact',
    'impacted',
    'impaction',
    'impacts',
    'impair',
    'impaired',
    'impairer',
    'impairers',
    'impairing',
    'impairment',
    'impairments',
    'impairs',
    'impala',
    'impalas',
    'impale',
    'impaled',
    'impalement',
    'impaling',
    'impalpability',
    'impalpable',
    'impanel',
    'imparipinnate',
    'impart',
    'impartation',
    'imparted',
    'impartial',
    'impartiality',
    'impartially',
    'imparting',
    'imparts',
    'impassable',
    'impasse',
    'impassioned',
    'impassive',
    'impassiveness',
    'impassivity',
    'impasto',
    'impatience',
    'impatient',
    'impatiently',
    'impeach',
    'impeachability',
    'impeached',
    'impeachment',
    'impeccability',
    'impeccable',
    'impeccant',
    'impecunious',
    'impecuniousness',
    'impedance',
    'impede',
    'impeded',
    'impedes',
    'impediment',
    'impedimenta',
    'impeding',
    'impel',
    'impelled',
    'impellent',
    'impeller',
    'impelling',
    'impend',
    'impendence',
    'impendency',
    'impendent',
    'impending',
    'impenetrability',
    'impenetrable',
    'impenetrableness',
    'impenitence',
    'impenitency',
    'impenitent',
    'imperative',
    'imperativeness',
    'imperceptibility',
    'imperceptible',
    'imperceptibly',
    'imperfect',
    'imperfectibility',
    'imperfectible',
    'imperfection',
    'imperfections',
    'imperfective',
    'imperfectly',
    'imperfectness',
    'imperforate',
    'imperial',
    'imperialism',
    'imperialist',
    'imperialistic',
    'imperil',
    'imperious',
    'imperiousness',
    'imperishability',
    'imperishable',
    'imperishableness',
    'imperishingness',
    'imperium',
    'impermanence',
    'impermanency',
    'impermanent',
    'impermeability',
    'impermeable',
    'impermeableness',
    'impermissibility',
    'impermissible',
    'impersonal',
    'impersonate',
    'impersonates',
    'impersonation',
    'impersonator',
    'impertinence',
    'impertinent',
    'imperturbability',
    'imperturbable',
    'imperturbableness',
    'imperviable',
    'impervious',
    'imperviousness',
    'impetiginous',
    'impetigo',
    'impetuosity',
    'impetuous',
    'impetuousness',
    'impetus',
    'impiety',
    'impinge',
    'impingement',
    'impinges',
    'impinging',
    'impious',
    'impiousness',
    'impish',
    'impishness',
    'implacable',
    'implant',
    'implantation',
    'implanted',
    'implanting',
    'implants',
    'implausibility',
    'implausible',
    'implausibleness',
    'implement',
    'implemental',
    'implementation',
    'implemented',
    'implementing',
    'implements',
    'implicate',
    'implicated',
    'implicates',
    'implication',
    'implicational',
    'implications',
    'implicative',
    'implicit',
    'implicitness',
    'implied',
    'implies',
    'implike',
    'implode',
    'implore',
    'imploring',
    'implosion',
    'imply',
    'implying',
    'impolicy',
    'impolite',
    'impolitely',
    'impoliteness',
    'impolitic',
    'imponderable',
    'import',
    'importance',
    'important',
    'importation',
    'imported',
    'importee',
    'importer',
    'importing',
    'imports',
    'importunate',
    'importune',
    'importunity',
    'impose',
    'imposed',
    'imposes',
    'imposing',
    'imposingly',
    'imposition',
    'impossibility',
    'impossible',
    'impossibleness',
    'impossibly',
    'impost',
    'imposter',
    'impostor',
    'imposture',
    'impotence',
    'impotency',
    'impotent',
    'impound',
    'impounded',
    'impounding',
    'impoundment',
    'impoverish',
    'impoverished',
    'impoverishment',
    'impracticability',
    'impracticable',
    'impracticableness',
    'impractical',
    'impracticality',
    'imprecate',
    'imprecation',
    'imprecations',
    'imprecise',
    'impreciseness',
    'imprecision',
    'impregnability',
    'impregnable',
    'impregnate',
    'impregnated',
    'impregnates',
    'impregnation',
    'impresario',
    'impress',
    'impressed',
    'impressible',
    'impressing',
    'impression',
    'impressionable',
    'impressionism',
    'impressionist',
    'impressionistic',
    'impressionists',
    'impressions',
    'impressive',
    'impressively',
    'impressiveness',
    'impressment',
    'imprimatur',
    'imprint',
    'imprinted',
    'imprinting',
    'imprints',
    'imprison',
    'imprisoned',
    'imprisoning',
    'imprisonment',
    'improbability',
    'improbable',
    'improbableness',
    'impromptu',
    'improper',
    'improperly',
    'improperness',
    'impropriety',
    'improvable',
    'improve',
    'improved',
    'improvement',
    'improvements',
    'improver',
    'improves',
    'improvidence',
    'improvident',
    'improving',
    'improvisation',
    'improvise',
    'improvised',
    'improvising',
    'improvize',
    'imprudence',
    'imprudent',
    'imprudently',
    'impudence',
    'impudent',
    'impudently',
    'impugn',
    'impugnable',
    'impuissance',
    'impuissant',
    'impulse',
    'impulses',
    'impulsion',
    'impulsive',
    'impulsiveness',
    'impunity',
    'impure',
    'impureness',
    'impurities',
    'impurity',
    'imputable',
    'imputation',
    'impute',
    'imputed',
    'imputes',
    'imputing',
    'imputrescible',
    'imu',
    'imuran',
    'in',
    'inability',
    'inaccessibility',
    'inaccessible',
    'inaccessibly',
    'inaccuracy',
    'inaccurate',
    'inachis',
    'inaction',
    'inactivate',
    'inactivated',
    'inactivates',
    'inactivation',
    'inactive',
    'inactiveness',
    'inactivity',
    'inadequacy',
    'inadequate',
    'inadequately',
    'inadequateness',
    'inadmissibility',
    'inadmissible',
    'inadvertence',
    'inadvertency',
    'inadvertent',
    'inadvertently',
    'inadvisability',
    'inadvisable',
    'inaesthetic',
    'inalienable',
    'inalienably',
    'inalterable',
    'inamorata',
    'inamorato',
    'inane',
    'inanimate',
    'inanimateness',
    'inanition',
    'inanity',
    'inanna',
    'inapplicability',
    'inapplicable',
    'inapposite',
    'inappositeness',
    'inappreciable',
    'inappropriate',
    'inappropriately',
    'inappropriateness',
    'inapt',
    'inaptitude',
    'inaptness',
    'inarguable',
    'inarticulate',
    'inartistic',
    'inasmuch',
    'inattention',
    'inattentive',
    'inattentiveness',
    'inaudibility',
    'inaudible',
    'inaudibleness',
    'inaugural',
    'inaugurate',
    'inaugurated',
    'inauguration',
    'inauspicious',
    'inauspiciousness',
    'inauthentic',
    'inboard',
    'inborn',
    'inbound',
    'inbred',
    'inbreeding',
    'inbuilt',
    'inc',
    'inca',
    'incalculable',
    'incalescence',
    'incan',
    'incandesce',
    'incandescence',
    'incandescent',
    'incandescing',
    'incantation',
    'incantations',
    'incapability',
    'incapable',
    'incapableness',
    'incapacitate',
    'incapacitated',
    'incapacitating',
    'incapacity',
    'incarcerate',
    'incarcerated',
    'incarceration',
    'incarnadine',
    'incarnate',
    'incarnated',
    'incarnation',
    'incas',
    'incase',
    'incased',
    'incasement',
    'incaution',
    'incautious',
    'incautiousness',
    'incendiarism',
    'incendiary',
    'incense',
    'incensed',
    'incentive',
    'inception',
    'inceptive',
    'incertain',
    'incertitude',
    'incessancy',
    'incessant',
    'incessantly',
    'incessantness',
    'incest',
    'incestuous',
    'inch',
    'incheon',
    'inches',
    'inchoate',
    'inchoative',
    'inchon',
    'inchworm',
    'incidence',
    'incident',
    'incidental',
    'incidentally',
    'incidents',
    'incienso',
    'incinerate',
    'incinerated',
    'incinerates',
    'incinerating',
    'incineration',
    'incinerator',
    'incipience',
    'incipiency',
    'incipient',
    'incise',
    'incised',
    'incision',
    'incisions',
    'incisive',
    'incisiveness',
    'incisor',
    'incisors',
    'incisura',
    'incisure',
    'incitation',
    'incite',
    'incitement',
    'inciter',
    'incites',
    'inciting',
    'incitive',
    'incivility',
    'inclemency',
    'inclement',
    'inclementness',
    'inclination',
    'inclinations',
    'incline',
    'inclined',
    'inclines',
    'inclining',
    'inclinometer',
    'inclose',
    'inclosure',
    'include',
    'included',
    'includes',
    'including',
    'inclusion',
    'inclusive',
    'incognizable',
    'incognizance',
    'incognizant',
    'incognoscible',
    'incoherence',
    'incoherency',
    'incoherent',
    'incombustible',
    'income',
    'incomes',
    'incoming',
    'incommensurable',
    'incommensurate',
    'incommode',
    'incommodious',
    'incommodiousness',
    'incommunicado',
    'incommunicative',
    'incommutability',
    'incommutable',
    'incomparable',
    'incompatibility',
    'incompatible',
    'incompetence',
    'incompetency',
    'incompetent',
    'incomplete',
    'incompletely',
    'incompleteness',
    'incomprehensibility',
    'incomprehensible',
    'incomprehension',
    'incomprehensive',
    'incompressibility',
    'incompressible',
    'incomputable',
    'inconceivability',
    'inconceivable',
    'inconceivableness',
    'inconceivably',
    'inconclusive',
    'inconclusiveness',
    'inconel',
    'incongruent',
    'incongruity',
    'incongruous',
    'incongruousness',
    'inconsequence',
    'inconsequent',
    'inconsequential',
    'inconsiderable',
    'inconsiderate',
    'inconsiderately',
    'inconsiderateness',
    'inconsideration',
    'inconsistencies',
    'inconsistency',
    'inconsistent',
    'inconsolable',
    'inconspicuous',
    'inconspicuously',
    'inconspicuousness',
    'inconstancy',
    'inconstant',
    'incontestable',
    'incontestible',
    'incontinence',
    'incontinency',
    'incontinent',
    'incontrovertibility',
    'incontrovertible',
    'incontrovertibleness',
    'inconvenience',
    'inconvenienced',
    'inconvenient',
    'inconveniently',
    'inconvertibility',
    'inconvertible',
    'incoordination',
    'incorporate',
    'incorporated',
    'incorporates',
    'incorporating',
    'incorporation',
    'incorporative',
    'incorporeal',
    'incorporeality',
    'incorrect',
    'incorrectly',
    'incorrectness',
    'incorrigible',
    'incorrigibly',
    'incorrupt',
    'incorrupted',
    'incorruptibility',
    'incorruptible',
    'incorruption',
    'incorruptness',
    'increase',
    'increased',
    'increases',
    'increasing',
    'increasingly',
    'incredibility',
    'incredible',
    'incredibleness',
    'incredulity',
    'incredulous',
    'increment',
    'incremental',
    'increments',
    'incriminate',
    'incriminates',
    'incriminating',
    'incrimination',
    'incriminatory',
    'incrust',
    'incrustation',
    'incubate',
    'incubates',
    'incubation',
    'incubator',
    'incubus',
    'inculcate',
    'inculcation',
    'inculpability',
    'inculpable',
    'inculpableness',
    'inculpate',
    'inculpation',
    'inculpative',
    'inculpatory',
    'incumbency',
    'incumbent',
    'incumbrance',
    'incur',
    'incurability',
    'incurable',
    'incurableness',
    'incurably',
    'incurious',
    'incurred',
    'incurrence',
    'incurring',
    'incursion',
    'incursive',
    'incurvate',
    'incurvates',
    'incurvation',
    'incurvature',
    'incurved',
    'incus',
    'indaba',
    'indapamide',
    'indebted',
    'indebtedness',
    'indecency',
    'indecent',
    'indecipherable',
    'indecision',
    'indecisive',
    'indecisiveness',
    'indecorous',
    'indecorousness',
    'indecorum',
    'indefatigability',
    'indefatigable',
    'indefatigableness',
    'indefeasible',
    'indefensible',
    'indefinable',
    'indefinite',
    'indefinitely',
    'indefiniteness',
    'indefinity',
    'indehiscent',
    'indelible',
    'indelicacy',
    'indelicate',
    'indemnification',
    'indemnifies',
    'indemnify',
    'indemnity',
    'indene',
    'indent',
    'indentation',
    'indentations',
    'indented',
    'indention',
    'indenture',
    'indentured',
    'independence',
    'independency',
    'independent',
    'independently',
    'inderal',
    'indescribable',
    'indestructibility',
    'indestructible',
    'indeterminable',
    'indeterminacy',
    'indeterminate',
    'indeterminateness',
    'indetermination',
    'index',
    'indexation',
    'indexed',
    'indexer',
    'indexes',
    'indexical',
    'indexing',
    'indexless',
    'india',
    'indiaman',
    'indian',
    'indiana',
    'indianan',
    'indianapolis',
    'indians',
    'indic',
    'indicant',
    'indicants',
    'indicate',
    'indicated',
    'indicates',
    'indicating',
    'indication',
    'indications',
    'indicative',
    'indicator',
    'indicatoridae',
    'indicators',
    'indicatory',
    'indict',
    'indictability',
    'indictable',
    'indicted',
    'indiction',
    'indictment',
    'indictments',
    'indicus',
    'indie',
    'indies',
    'indifference',
    'indifferent',
    'indigen',
    'indigence',
    'indigene',
    'indigenous',
    'indigenousness',
    'indigent',
    'indigestibility',
    'indigestible',
    'indigestibleness',
    'indigestion',
    'indigirka',
    'indignant',
    'indignation',
    'indignity',
    'indigo',
    'indigofera',
    'indigotin',
    'indinavir',
    'indirect',
    'indirection',
    'indirections',
    'indirectly',
    'indirectness',
    'indiscernible',
    'indiscipline',
    'indiscreet',
    'indiscreetly',
    'indiscreetness',
    'indiscrete',
    'indiscretion',
    'indiscretions',
    'indiscriminate',
    'indiscriminately',
    'indiscriminating',
    'indispensability',
    'indispensable',
    'indispensableness',
    'indispose',
    'indisposed',
    'indisposition',
    'indisputability',
    'indisputable',
    'indissoluble',
    'indistinct',
    'indistinctly',
    'indistinctness',
    'indistinguishability',
    'indistinguishable',
    'indite',
    'indium',
    'individual',
    'individualisation',
    'individualise',
    'individualised',
    'individualism',
    'individualist',
    'individualistic',
    'individualistically',
    'individuality',
    'individualization',
    'individualize',
    'individualized',
    'individually',
    'individuals',
    'individuate',
    'individuates',
    'individuating',
    'individuation',
    'indivisible',
    'indochina',
    'indocile',
    'indocin',
    'indoctrinate',
    'indoctrination',
    'indolence',
    'indolent',
    'indomethacin',
    'indomitability',
    'indomitable',
    'indonesia',
    'indonesian',
    'indoor',
    'indoors',
    'indorse',
    'indorsement',
    'indorser',
    'indra',
    'indrawn',
    'indri',
    'indriidae',
    'indris',
    'indubitability',
    'indubitable',
    'induce',
    'induced',
    'inducement',
    'inducer',
    'induces',
    'inducing',
    'inducive',
    'induct',
    'inductance',
    'inducted',
    'inductee',
    'inductees',
    'induction',
    'inductive',
    'inductor',
    'indue',
    'indulge',
    'indulged',
    'indulgence',
    'indulgences',
    'indulgent',
    'indulges',
    'indulging',
    'indument',
    'indumentum',
    'indurate',
    'induration',
    'indus',
    'indusia',
    'indusial',
    'indusium',
    'industrial',
    'industrialisation',
    'industrialise',
    'industrialised',
    'industrialism',
    'industrialist',
    'industrialization',
    'industrialize',
    'industrialized',
    'industries',
    'industrious',
    'industriousness',
    'industry',
    'indwell',
    'indweller',
    'indwelling',
    'inebriant',
    'inebriate',
    'inebriated',
    'inebriation',
    'inebriety',
    'inedible',
    'ineffable',
    'ineffective',
    'ineffectiveness',
    'ineffectual',
    'ineffectuality',
    'ineffectualness',
    'inefficacious',
    'inefficaciousness',
    'inefficacy',
    'inefficiency',
    'inefficient',
    'inefficiently',
    'inelaborate',
    'inelastic',
    'inelasticity',
    'inelegance',
    'inelegant',
    'ineligibility',
    'ineligible',
    'ineluctability',
    'ineluctable',
    'inept',
    'ineptitude',
    'ineptness',
    'inequality',
    'inequitable',
    'inequities',
    'inequity',
    'ineradicable',
    'inerrable',
    'inerrancy',
    'inerrant',
    'inert',
    'inertia',
    'inertial',
    'inertness',
    'inescapable',
    'inessential',
    'inessentiality',
    'inestimable',
    'inevitability',
    'inevitable',
    'inevitableness',
    'inevitably',
    'inexact',
    'inexactitude',
    'inexactness',
    'inexcusable',
    'inexhaustible',
    'inexorability',
    'inexorable',
    'inexorableness',
    'inexpedience',
    'inexpediency',
    'inexpedient',
    'inexpensive',
    'inexpensiveness',
    'inexperience',
    'inexperienced',
    'inexperient',
    'inexpert',
    'inexpiable',
    'inexplicable',
    'inexplicit',
    'inexplicitness',
    'inexpressible',
    'inexpressibly',
    'inexpressive',
    'inexpugnable',
    'inexpungeable',
    'inexpungible',
    'inextensible',
    'inexterminable',
    'inextinguishable',
    'inextirpable',
    'inextricable',
    'infallibility',
    'infallible',
    'infamous',
    'infamy',
    'infancy',
    'infant',
    'infanticide',
    'infantile',
    'infantilism',
    'infantry',
    'infantryman',
    'infantrymen',
    'infants',
    'infarct',
    'infarction',
    'infatuate',
    'infatuated',
    'infatuation',
    'infatuations',
    'infeasibility',
    'infeasible',
    'infect',
    'infected',
    'infecting',
    'infection',
    'infections',
    'infectious',
    'infective',
    'infects',
    'infelicitous',
    'infelicity',
    'infer',
    'inference',
    'inferences',
    'inferential',
    'inferior',
    'inferiority',
    'inferiors',
    'infernal',
    'infernals',
    'inferno',
    'inferred',
    'inferring',
    'infertile',
    'infertility',
    'infest',
    'infestans',
    'infestation',
    'infestations',
    'infested',
    'infesting',
    'infests',
    'infidel',
    'infidelity',
    'infield',
    'infielder',
    'infiltrate',
    'infiltrated',
    'infiltration',
    'infiltrator',
    'infinite',
    'infinitely',
    'infiniteness',
    'infinitesimal',
    'infinitival',
    'infinitive',
    'infinitude',
    'infinity',
    'infirm',
    'infirmary',
    'infirmity',
    'infix',
    'inflame',
    'inflamed',
    'inflaming',
    'inflammability',
    'inflammable',
    'inflammation',
    'inflammatory',
    'inflatable',
    'inflate',
    'inflated',
    'inflater',
    'inflates',
    'inflation',
    'inflationary',
    'inflator',
    'inflect',
    'inflected',
    'inflection',
    'inflectional',
    'inflections',
    'inflexibility',
    'inflexible',
    'inflexibleness',
    'inflexibly',
    'inflexion',
    'inflict',
    'inflicted',
    'inflicting',
    'infliction',
    'inflicts',
    'infliximab',
    'inflorescence',
    'inflorescences',
    'inflow',
    'inflowing',
    'influence',
    'influenced',
    'influences',
    'influencing',
    'influent',
    'influential',
    'influenza',
    'influx',
    'info',
    'infolding',
    'infomercial',
    'inform',
    'informal',
    'informality',
    'informally',
    'informant',
    'informatics',
    'information',
    'informational',
    'informative',
    'informatory',
    'informed',
    'informer',
    'informercial',
    'informing',
    'informs',
    'infotainment',
    'infra',
    'infract',
    'infraction',
    'infrahuman',
    'inframaxillary',
    'infrangible',
    'infrared',
    'infrasonic',
    'infrastructure',
    'infrequency',
    'infrequent',
    'infrequently',
    'infrigidation',
    'infringe',
    'infringement',
    'infructescence',
    'infundibulum',
    'infuriate',
    'infuriated',
    'infuriating',
    'infuriation',
    'infuscate',
    'infuse',
    'infused',
    'infuses',
    'infusing',
    'infusion',
    'infusions',
    'infusoria',
    'infusorian',
    'inga',
    'ingathering',
    'inge',
    'ingeminate',
    'ingenious',
    'ingeniousness',
    'ingenue',
    'ingenuity',
    'ingenuous',
    'ingenuousness',
    'inger',
    'ingerman',
    'ingest',
    'ingesta',
    'ingested',
    'ingesting',
    'ingestion',
    'ingests',
    'inglenook',
    'inglorious',
    'ingot',
    'ingots',
    'ingraft',
    'ingrain',
    'ingrained',
    'ingraining',
    'ingrate',
    'ingratiate',
    'ingratiating',
    'ingratiation',
    'ingratiatory',
    'ingratitude',
    'ingredient',
    'ingredients',
    'ingres',
    'ingress',
    'ingrian',
    'ingroup',
    'ingrowing',
    'ingrown',
    'ingrowth',
    'inguen',
    'inguinal',
    'inguinale',
    'ingurgitate',
    'inh',
    'inhabit',
    'inhabitable',
    'inhabitancy',
    'inhabitant',
    'inhabitants',
    'inhabitation',
    'inhabited',
    'inhabiting',
    'inhabits',
    'inhalant',
    'inhalation',
    'inhalator',
    'inhale',
    'inhaled',
    'inhaler',
    'inhales',
    'inhaling',
    'inharmonic',
    'inharmonious',
    'inharmoniousness',
    'inhere',
    'inherence',
    'inherency',
    'inherent',
    'inherently',
    'inheres',
    'inherit',
    'inheritable',
    'inheritance',
    'inherited',
    'inheriting',
    'inheritor',
    'inheritress',
    'inheritrix',
    'inherits',
    'inhibit',
    'inhibited',
    'inhibiting',
    'inhibition',
    'inhibitor',
    'inhibitors',
    'inhibitory',
    'inhibits',
    'inhomogeneity',
    'inhomogeneous',
    'inhospitable',
    'inhospitableness',
    'inhospitality',
    'inhuman',
    'inhumane',
    'inhumaneness',
    'inhumanity',
    'inhumation',
    'inhume',
    'inhumed',
    'inimical',
    'inimitable',
    'inion',
    'iniquitous',
    'iniquity',
    'initial',
    'initialisation',
    'initialise',
    'initialism',
    'initialization',
    'initialize',
    'initially',
    'initials',
    'initiate',
    'initiated',
    'initiates',
    'initiating',
    'initiation',
    'initiative',
    'initiator',
    'initiatory',
    'inject',
    'injectable',
    'injectant',
    'injected',
    'injecting',
    'injection',
    'injections',
    'injector',
    'injects',
    'injudicious',
    'injudiciousness',
    'injun',
    'injunction',
    'injunctions',
    'injure',
    'injured',
    'injures',
    'injuries',
    'injuring',
    'injurious',
    'injuriousness',
    'injury',
    'injustice',
    'injustices',
    'ink',
    'inka',
    'inkberry',
    'inkblot',
    'inked',
    'inkeles',
    'inkiness',
    'inkle',
    'inkling',
    'inkpad',
    'inkpot',
    'inks',
    'inkstand',
    'inkwell',
    'inky',
    'inla',
    'inlaid',
    'inland',
    'inlay',
    'inlaying',
    'inlays',
    'inlet',
    'inmarriage',
    'inmarry',
    'inmate',
    'inmates',
    'inmost',
    'inn',
    'innards',
    'innate',
    'innately',
    'innateness',
    'inner',
    'innermost',
    'innersole',
    'innervate',
    'innervated',
    'innervating',
    'innervation',
    'inning',
    'innings',
    'innkeeper',
    'innocence',
    'innocencies',
    'innocency',
    'innocense',
    'innocent',
    'innocuous',
    'innominate',
    'innovate',
    'innovation',
    'innovational',
    'innovations',
    'innovative',
    'innovativeness',
    'innovator',
    'innoxious',
    'innsbruck',
    'innuendo',
    'innumerable',
    'innumerableness',
    'innumerate',
    'innumerous',
    'inocor',
    'inoculant',
    'inoculate',
    'inoculated',
    'inoculates',
    'inoculating',
    'inoculation',
    'inoculator',
    'inoculum',
    'inodorous',
    'inoffensive',
    'inoperable',
    'inoperative',
    'inopportune',
    'inopportuneness',
    'inordinate',
    'inordinateness',
    'inorganic',
    'inosculate',
    'inosculation',
    'inosine',
    'inositol',
    'inpatient',
    'inpour',
    'inpouring',
    'input',
    'inputs',
    'inquest',
    'inquietude',
    'inquire',
    'inquired',
    'inquirer',
    'inquiries',
    'inquiring',
    'inquiringly',
    'inquiry',
    'inquisition',
    'inquisitive',
    'inquisitively',
    'inquisitiveness',
    'inquisitor',
    'inquisitorial',
    'inquisitory',
    'inr',
    'inroad',
    'inroads',
    'inrush',
    'ins',
    'insalubrious',
    'insalubriousness',
    'insalubrity',
    'insane',
    'insanely',
    'insaneness',
    'insanitary',
    'insanity',
    'insatiable',
    'insatiably',
    'insatiate',
    'inscribe',
    'inscribed',
    'inscribing',
    'inscription',
    'inscriptions',
    'inscriptive',
    'inscrutability',
    'inscrutable',
    'insect',
    'insecta',
    'insectan',
    'insecticidal',
    'insecticide',
    'insecticides',
    'insectifuge',
    'insectivora',
    'insectivore',
    'insectivores',
    'insectivorous',
    'insects',
    'insecure',
    'insecureness',
    'insecurity',
    'inseminate',
    'inseminated',
    'insemination',
    'insensate',
    'insensibility',
    'insensible',
    'insensitive',
    'insensitiveness',
    'insensitivity',
    'insentience',
    'insentient',
    'inseparable',
    'inseparably',
    'insert',
    'inserted',
    'inserting',
    'insertion',
    'insertions',
    'inserts',
    'insessores',
    'inset',
    'inshore',
    'inside',
    'insider',
    'insidious',
    'insidiousness',
    'insight',
    'insightful',
    'insightfulness',
    'insights',
    'insignia',
    'insignificance',
    'insignificant',
    'insignificantly',
    'insincere',
    'insincerely',
    'insincerity',
    'insinuate',
    'insinuated',
    'insinuating',
    'insinuation',
    'insipid',
    'insipidity',
    'insipidness',
    'insipidus',
    'insist',
    'insisted',
    'insistence',
    'insistency',
    'insistent',
    'insistently',
    'insisting',
    'insists',
    'insobriety',
    'insolate',
    'insolation',
    'insole',
    'insolence',
    'insolent',
    'insolubility',
    'insoluble',
    'insolvable',
    'insolvency',
    'insolvent',
    'insomnia',
    'insomniac',
    'insouciance',
    'insouciant',
    'inspan',
    'inspect',
    'inspected',
    'inspecting',
    'inspection',
    'inspections',
    'inspector',
    'inspectorate',
    'inspectors',
    'inspectorship',
    'inspects',
    'inspiration',
    'inspirational',
    'inspirations',
    'inspiratory',
    'inspire',
    'inspired',
    'inspirer',
    'inspires',
    'inspiring',
    'inspirit',
    'inspiriting',
    'inspissate',
    'inspissation',
    'inst',
    'instability',
    'instal',
    'install',
    'installation',
    'installations',
    'installed',
    'installing',
    'installment',
    'installments',
    'installs',
    'instalment',
    'instance',
    'instances',
    'instancy',
    'instant',
    'instantaneous',
    'instantaneously',
    'instantaneousness',
    'instantiate',
    'instantiates',
    'instantiation',
    'instantiations',
    'instantly',
    'instants',
    'instar',
    'instauration',
    'instead',
    'instep',
    'instigant',
    'instigate',
    'instigated',
    'instigates',
    'instigation',
    'instigative',
    'instigator',
    'instil',
    'instill',
    'instillation',
    'instillator',
    'instilled',
    'instilling',
    'instillment',
    'instilment',
    'instinct',
    'instinctive',
    'instinctively',
    'instincts',
    'institute',
    'instituted',
    'institutes',
    'institution',
    'institutional',
    'institutionalise',
    'institutionalised',
    'institutionalize',
    'institutionalized',
    'institutions',
    'instroke',
    'instruct',
    'instructed',
    'instructing',
    'instruction',
    'instructional',
    'instructions',
    'instructive',
    'instructor',
    'instructors',
    'instructorship',
    'instructress',
    'instructs',
    'instrument',
    'instrumental',
    'instrumentalism',
    'instrumentalist',
    'instrumentalists',
    'instrumentalities',
    'instrumentality',
    'instrumentate',
    'instrumentation',
    'instruments',
    'insubordinate',
    'insubordination',
    'insubstantial',
    'insubstantiality',
    'insufferable',
    'insufferably',
    'insufficiencies',
    'insufficiency',
    'insufficient',
    'insufficiently',
    'insufflate',
    'insufflation',
    'insulant',
    'insular',
    'insularism',
    'insularity',
    'insulate',
    'insulated',
    'insulates',
    'insulating',
    'insulation',
    'insulator',
    'insulators',
    'insulin',
    'insult',
    'insulted',
    'insulting',
    'insults',
    'insuperable',
    'insupportable',
    'insurability',
    'insurable',
    'insurance',
    'insure',
    'insured',
    'insurer',
    'insures',
    'insurgence',
    'insurgency',
    'insurgent',
    'insurgents',
    'insuring',
    'insurmountable',
    'insurrection',
    'insurrectional',
    'insurrectionary',
    'insurrectionism',
    'insurrectionist',
    'insusceptible',
    'intact',
    'intactness',
    'intaglio',
    'intake',
    'intangibility',
    'intangible',
    'intangibleness',
    'integer',
    'integers',
    'integral',
    'integrality',
    'integrals',
    'integrate',
    'integrated',
    'integrates',
    'integrating',
    'integration',
    'integrative',
    'integrator',
    'integrity',
    'integument',
    'integumental',
    'integumentary',
    'intellect',
    'intellection',
    'intellects',
    'intellectual',
    'intellectualisation',
    'intellectualization',
    'intellectually',
    'intellectuals',
    'intelligence',
    'intelligent',
    'intelligently',
    'intelligentsia',
    'intelligibility',
    'intelligible',
    'intelnet',
    'intemperance',
    'intemperate',
    'intemperateness',
    'intend',
    'intended',
    'intending',
    'intends',
    'intense',
    'intensely',
    'intensification',
    'intensified',
    'intensifier',
    'intensify',
    'intensifying',
    'intension',
    'intensional',
    'intensity',
    'intensive',
    'intensively',
    'intensiveness',
    'intensol',
    'intent',
    'intention',
    'intentional',
    'intentionality',
    'intentionally',
    'intentions',
    'intently',
    'intentness',
    'inter',
    'interact',
    'interacting',
    'interaction',
    'interactional',
    'interactions',
    'interactive',
    'interacts',
    'interahamwe',
    'interbrain',
    'interbred',
    'interbreed',
    'interbreeding',
    'interbreeds',
    'intercalary',
    'intercalate',
    'intercalation',
    'intercede',
    'interceded',
    'intercellular',
    'intercept',
    'intercepted',
    'interception',
    'interceptor',
    'intercession',
    'intercessor',
    'interchange',
    'interchangeability',
    'interchangeable',
    'interchangeableness',
    'interchangeably',
    'interchanged',
    'interchanging',
    'interchurch',
    'intercollegiate',
    'intercom',
    'intercommunicate',
    'intercommunication',
    'intercommunion',
    'interconnect',
    'interconnected',
    'interconnectedness',
    'interconnecting',
    'interconnection',
    'interconnections',
    'intercontinental',
    'intercorporate',
    'intercostal',
    'intercourse',
    'intercrossed',
    'interdenominational',
    'interdepartmental',
    'interdepend',
    'interdependence',
    'interdependency',
    'interdependent',
    'interdict',
    'interdiction',
    'interdisciplinary',
    'interest',
    'interested',
    'interestedness',
    'interesting',
    'interestingness',
    'interests',
    'interface',
    'interfaces',
    'interfacial',
    'interfaith',
    'interfere',
    'interfered',
    'interference',
    'interferes',
    'interfering',
    'interferometer',
    'interferon',
    'intergalactic',
    'interim',
    'interior',
    'interiorise',
    'interiorize',
    'interiors',
    'interject',
    'interjected',
    'interjecting',
    'interjection',
    'interlace',
    'interlaced',
    'interlaces',
    'interlacing',
    'interlaken',
    'interlanguage',
    'interlard',
    'interlayer',
    'interleaf',
    'interleave',
    'interleaved',
    'interleukin',
    'interlibrary',
    'interlineal',
    'interlinear',
    'interlingua',
    'interlink',
    'interlinked',
    'interlinking',
    'interlobular',
    'interlock',
    'interlocked',
    'interlocking',
    'interlocks',
    'interlocutor',
    'interlocutors',
    'interlocutory',
    'interlope',
    'interloper',
    'interlude',
    'interluded',
    'interludes',
    'intermarriage',
    'intermarriages',
    'intermarry',
    'intermaxillary',
    'intermediary',
    'intermediate',
    'intermediation',
    'intermediator',
    'interment',
    'intermeshed',
    'intermezzo',
    'interminable',
    'intermingle',
    'intermission',
    'intermit',
    'intermittence',
    'intermittency',
    'intermittent',
    'intermittently',
    'intermix',
    'intermixed',
    'intermixture',
    'intermolecular',
    'intermural',
    'intern',
    'internal',
    'internalisation',
    'internalise',
    'internality',
    'internalization',
    'internalize',
    'internalized',
    'internally',
    'international',
    'internationale',
    'internationalisation',
    'internationalise',
    'internationalism',
    'internationalist',
    'internationalistic',
    'internationality',
    'internationalization',
    'internationalize',
    'internationalized',
    'internationally',
    'interne',
    'internecine',
    'interned',
    'internee',
    'internees',
    'internet',
    'interning',
    'internist',
    'internment',
    'internode',
    'internship',
    'internuncio',
    'interoception',
    'interoceptive',
    'interoceptor',
    'interoperability',
    'interoperable',
    'interpellate',
    'interpellation',
    'interpenetrate',
    'interpenetration',
    'interpersonal',
    'interphone',
    'interplanetary',
    'interplay',
    'interpol',
    'interpolate',
    'interpolation',
    'interpolations',
    'interpose',
    'interposed',
    'interposes',
    'interposing',
    'interposition',
    'interpret',
    'interpretable',
    'interpretation',
    'interpretations',
    'interpretative',
    'interpreted',
    'interpreter',
    'interpreters',
    'interpreting',
    'interpretive',
    'interprets',
    'interracial',
    'interred',
    'interreflection',
    'interregnum',
    'interrelate',
    'interrelated',
    'interrelatedness',
    'interrelation',
    'interrelations',
    'interrelationship',
    'interrogate',
    'interrogating',
    'interrogation',
    'interrogative',
    'interrogator',
    'interrogatory',
    'interrupt',
    'interrupted',
    'interrupter',
    'interrupting',
    'interruption',
    'interruptions',
    'interrupts',
    'interscholastic',
    'interschool',
    'intersect',
    'intersectant',
    'intersected',
    'intersecting',
    'intersection',
    'intersections',
    'intersects',
    'intersex',
    'intersexual',
    'interspecies',
    'interspecific',
    'interspersal',
    'intersperse',
    'interspersed',
    'interspersion',
    'interstate',
    'interstellar',
    'interstice',
    'interstices',
    'interstitial',
    'interstratify',
    'intertidal',
    'intertribal',
    'intertrigo',
    'intertwine',
    'intertwined',
    'intertwines',
    'intertwining',
    'interval',
    'intervals',
    'intervene',
    'intervened',
    'intervenes',
    'intervening',
    'intervenor',
    'intervention',
    'intervertebral',
    'interview',
    'interviewed',
    'interviewee',
    'interviewer',
    'interviewing',
    'interviews',
    'interweave',
    'interweaving',
    'interwoven',
    'intestacy',
    'intestate',
    'intestinal',
    'intestine',
    'intestines',
    'inti',
    'intifada',
    'intifadah',
    'intima',
    'intimacies',
    'intimacy',
    'intimal',
    'intimate',
    'intimated',
    'intimately',
    'intimation',
    'intimidate',
    'intimidated',
    'intimidates',
    'intimidating',
    'intimidation',
    'into',
    'intolerable',
    'intolerably',
    'intolerance',
    'intolerant',
    'intonate',
    'intonation',
    'intonations',
    'intone',
    'intoned',
    'intoxicant',
    'intoxicate',
    'intoxicated',
    'intoxicating',
    'intoxication',
    'intracellular',
    'intracerebral',
    'intracranial',
    'intractability',
    'intractable',
    'intractableness',
    'intractably',
    'intracutaneous',
    'intradepartmental',
    'intradermal',
    'intradermic',
    'intrados',
    'intragroup',
    'intralinguistic',
    'intralobular',
    'intramolecular',
    'intramural',
    'intramuscular',
    'intramuscularly',
    'intranet',
    'intransigence',
    'intransigency',
    'intransigent',
    'intransitive',
    'intransitiveness',
    'intransitivise',
    'intransitivity',
    'intransitivize',
    'intraocular',
    'intrapulmonary',
    'intrasentential',
    'intraspecies',
    'intraspecific',
    'intrastate',
    'intrauterine',
    'intravasation',
    'intravenous',
    'intravenously',
    'intraventricular',
    'intrench',
    'intrenchment',
    'intrepid',
    'intrepidity',
    'intricacy',
    'intricate',
    'intricately',
    'intrigue',
    'intrigued',
    'intriguer',
    'intrigues',
    'intriguing',
    'intrinsic',
    'intrinsical',
    'intrinsically',
    'intro',
    'introduce',
    'introduced',
    'introduces',
    'introducing',
    'introduction',
    'introductory',
    'introit',
    'introitus',
    'introject',
    'introjected',
    'introjection',
    'intromission',
    'intromit',
    'intron',
    'introns',
    'intropin',
    'introspect',
    'introspection',
    'introspective',
    'introspectiveness',
    'introuvable',
    'introversion',
    'introversive',
    'introvert',
    'introverted',
    'introvertish',
    'introvertive',
    'intrude',
    'intruded',
    'intruder',
    'intrudes',
    'intruding',
    'intrusion',
    'intrusive',
    'intrusiveness',
    'intrust',
    'intubate',
    'intubation',
    'intuit',
    'intuition',
    'intuitionism',
    'intuitionist',
    'intuitive',
    'intuitively',
    'intumesce',
    'intumescence',
    'intumescency',
    'intumescent',
    'intussuscept',
    'intussuscepted',
    'intussusception',
    'inuit',
    'inula',
    'inulin',
    'inunct',
    'inunction',
    'inundate',
    'inundated',
    'inundation',
    'inure',
    'inured',
    'inutile',
    'inutility',
    'invade',
    'invaded',
    'invader',
    'invaders',
    'invades',
    'invading',
    'invaginate',
    'invagination',
    'invalid',
    'invalidate',
    'invalidated',
    'invalidates',
    'invalidating',
    'invalidation',
    'invalidator',
    'invalidism',
    'invalidity',
    'invalidness',
    'invalids',
    'invaluable',
    'invaluableness',
    'invar',
    'invariability',
    'invariable',
    'invariableness',
    'invariably',
    'invariance',
    'invariant',
    'invasion',
    'invasions',
    'invasive',
    'invective',
    'invectives',
    'inveigh',
    'inveigle',
    'invent',
    'invented',
    'inventing',
    'invention',
    'inventions',
    'inventive',
    'inventiveness',
    'inventor',
    'inventories',
    'inventors',
    'inventory',
    'inventorying',
    'invents',
    'inverse',
    'inversely',
    'inversion',
    'invert',
    'invertase',
    'invertebrate',
    'invertebrates',
    'inverted',
    'inverter',
    'invertible',
    'inverts',
    'invest',
    'invested',
    'investigate',
    'investigated',
    'investigates',
    'investigating',
    'investigation',
    'investigations',
    'investigative',
    'investigator',
    'investigatory',
    'investing',
    'investiture',
    'investment',
    'investments',
    'investor',
    'investors',
    'invests',
    'inveterate',
    'invidia',
    'invidious',
    'invigilate',
    'invigilation',
    'invigilator',
    'invigorate',
    'invigorated',
    'invigorates',
    'invigorating',
    'invigoration',
    'invigorator',
    'invincibility',
    'invincible',
    'inviolable',
    'inviolate',
    'invirase',
    'invisibility',
    'invisible',
    'invisibleness',
    'invitation',
    'invitational',
    'invitatory',
    'invite',
    'invited',
    'invitee',
    'invites',
    'inviting',
    'invitingly',
    'invocation',
    'invocations',
    'invoice',
    'invoiced',
    'invoke',
    'invoked',
    'invokes',
    'invoking',
    'involucrate',
    'involucre',
    'involucres',
    'involuntarily',
    'involuntariness',
    'involuntary',
    'involute',
    'involution',
    'involve',
    'involved',
    'involvement',
    'involves',
    'involving',
    'invulnerability',
    'invulnerable',
    'inward',
    'inwardly',
    'inwardness',
    'inwards',
    'inweave',
    'inwrought',
    'io',
    'ioc',
    'iodide',
    'iodin',
    'iodinate',
    'iodinated',
    'iodinating',
    'iodination',
    'iodine',
    'iodise',
    'iodised',
    'iodize',
    'iodized',
    'iodochlorhydroxyquin',
    'iodocompound',
    'iodoform',
    'iodoprotein',
    'iodopsin',
    'iodothyronine',
    'iodotyrosine',
    'iol',
    'ion',
    'ionate',
    'ionesco',
    'ionia',
    'ionian',
    'ionians',
    'ionic',
    'ionisation',
    'ionise',
    'ionised',
    'ionization',
    'ionize',
    'ionized',
    'ionizes',
    'ionizing',
    'ionophoresis',
    'ionosphere',
    'ions',
    'iontophoresis',
    'iontotherapy',
    'iop',
    'iota',
    'iou',
    'iowa',
    'iowan',
    'ioway',
    'ip',
    'ipecac',
    'iphigenia',
    'ipidae',
    'ipo',
    'ipod',
    'ipomoea',
    'iproclozide',
    'ipsedixitism',
    'ipsilateral',
    'ipsus',
    'ipv',
    'iq',
    'ir',
    'ira',
    'irak',
    'iraki',
    'iran',
    'irani',
    'iranian',
    'iraq',
    'iraqi',
    'iraqis',
    'irascibility',
    'irascible',
    'irate',
    'ire',
    'ireful',
    'ireland',
    'irelander',
    'irena',
    'irenaeus',
    'irenic',
    'irenidae',
    'iresine',
    'iridaceae',
    'iridaceous',
    'iridectomy',
    'iridesce',
    'iridesced',
    'iridescence',
    'iridescent',
    'iridic',
    'iridium',
    'iridocyclitis',
    'iridokeratitis',
    'iridoncus',
    'iridoprocne',
    'iridosmine',
    'iridotomy',
    'iris',
    'irises',
    'irish',
    'irishman',
    'irishwoman',
    'iritic',
    'iritis',
    'irk',
    'irksome',
    'iron',
    'ironclad',
    'ironed',
    'ironic',
    'ironical',
    'ironically',
    'ironing',
    'ironist',
    'ironlike',
    'ironman',
    'ironmonger',
    'ironmongery',
    'irons',
    'ironshod',
    'ironside',
    'ironsides',
    'ironware',
    'ironweed',
    'ironwood',
    'ironwork',
    'ironworker',
    'ironworks',
    'irony',
    'iroquoian',
    'iroquois',
    'irradiate',
    'irradiated',
    'irradiating',
    'irradiation',
    'irrational',
    'irrationality',
    'irrationally',
    'irrawaddy',
    'irreality',
    'irreclaimable',
    'irreconcilable',
    'irrecoverable',
    'irredeemable',
    'irredenta',
    'irredentism',
    'irredentist',
    'irreducible',
    'irrefutable',
    'irregular',
    'irregularities',
    'irregularity',
    'irregularly',
    'irrelevance',
    'irrelevancy',
    'irrelevant',
    'irreligion',
    'irreligionist',
    'irreligious',
    'irreligiousness',
    'irremediable',
    'irremovable',
    'irreparable',
    'irreparably',
    'irreplaceable',
    'irreplaceableness',
    'irrepressibility',
    'irrepressible',
    'irreproachable',
    'irreproducibility',
    'irreproducible',
    'irresistibility',
    'irresistible',
    'irresistibleness',
    'irresolute',
    'irresoluteness',
    'irresolution',
    'irrespective',
    'irresponsibility',
    'irresponsible',
    'irresponsibleness',
    'irresponsibly',
    'irretrievable',
    'irreverence',
    'irreverent',
    'irreverently',
    'irreversibility',
    'irreversible',
    'irrevocable',
    'irrevocably',
    'irrevokable',
    'irridenta',
    'irridentism',
    'irridentist',
    'irrigate',
    'irrigated',
    'irrigating',
    'irrigation',
    'irritability',
    'irritable',
    'irritant',
    'irritants',
    'irritate',
    'irritated',
    'irritates',
    'irritating',
    'irritatingly',
    'irritation',
    'irritations',
    'irritative',
    'irrupt',
    'irrupted',
    'irruption',
    'irruptive',
    'irs',
    'irtish',
    'irtysh',
    'irula',
    'irving',
    'irvingia',
    'irwin',
    'is',
    'isaac',
    'isabella',
    'isaiah',
    'isarithm',
    'isatis',
    'ischaemia',
    'ischaemic',
    'ischemia',
    'ischemic',
    'ischia',
    'ischigualastia',
    'ischium',
    'isentropic',
    'isere',
    'iseult',
    'isfahan',
    'isherwood',
    'ishmael',
    'ishtar',
    'isi',
    'isinglass',
    'isis',
    'iskcon',
    'islam',
    'islamabad',
    'islamic',
    'islamise',
    'islamism',
    'islamist',
    'islamists',
    'islamiyah',
    'islamize',
    'islamized',
    'islamophobia',
    'island',
    'islander',
    'islands',
    'islay',
    'isle',
    'isles',
    'islet',
    'islets',
    'ism',
    'ismaili',
    'ismailian',
    'ismailism',
    'isn',
    'isoagglutination',
    'isoagglutinin',
    'isoagglutinogen',
    'isoantibody',
    'isobar',
    'isobilateral',
    'isobutylene',
    'isocarboxazid',
    'isochronal',
    'isochrone',
    'isochronous',
    'isoclinal',
    'isoclinic',
    'isocrates',
    'isocyanate',
    'isocyanic',
    'isocyclic',
    'isoetaceae',
    'isoetales',
    'isoetes',
    'isoflurane',
    'isogamete',
    'isogamy',
    'isogon',
    'isogone',
    'isogonic',
    'isogram',
    'isohel',
    'isolable',
    'isolate',
    'isolated',
    'isolates',
    'isolating',
    'isolation',
    'isolationism',
    'isolationist',
    'isolationistic',
    'isolde',
    'isoleucine',
    'isomer',
    'isomerase',
    'isomeric',
    'isomerisation',
    'isomerise',
    'isomerism',
    'isomerization',
    'isomerize',
    'isomers',
    'isometric',
    'isometrical',
    'isometrics',
    'isometries',
    'isometropia',
    'isometry',
    'isomorphic',
    'isomorphism',
    'isomorphous',
    'isomorphy',
    'isoniazid',
    'isopleth',
    'isopod',
    'isopoda',
    'isopods',
    'isopropanol',
    'isopropyl',
    'isoproterenol',
    'isoptera',
    'isopteran',
    'isoptin',
    'isopyrum',
    'isordil',
    'isosceles',
    'isosmotic',
    'isosorbide',
    'isospondyli',
    'isostasy',
    'isotherm',
    'isothermal',
    'isothermic',
    'isothiocyanate',
    'isotonic',
    'isotope',
    'isotopes',
    'isotopic',
    'isotropic',
    'isotropous',
    'isotropy',
    'israel',
    'israeli',
    'israelis',
    'israelite',
    'israelites',
    'issachar',
    'issuance',
    'issue',
    'issued',
    'issuer',
    'issues',
    'issuing',
    'issus',
    'istanbul',
    'isthmian',
    'isthmus',
    'istiophoridae',
    'istiophorus',
    'isuprel',
    'isuridae',
    'isurus',
    'it',
    'italia',
    'italian',
    'italians',
    'italic',
    'italica',
    'italicise',
    'italicize',
    'italics',
    'italy',
    'itch',
    'itchiness',
    'itching',
    'itchy',
    'item',
    'itemisation',
    'itemise',
    'itemization',
    'itemize',
    'itemized',
    'items',
    'iterate',
    'iteration',
    'iterative',
    'ithaca',
    'ithaki',
    'ithunn',
    'itinerant',
    'itinerary',
    'itinerate',
    'itinerating',
    'itineration',
    'itraconazole',
    'its',
    'itself',
    'iud',
    'iv',
    'iva',
    'ivan',
    'ivanov',
    'ives',
    'ivied',
    'ivory',
    'ivorybill',
    'ivp',
    'ivry',
    'ivy',
    'iw',
    'iwo',
    'iww',
    'ix',
    'ixc',
    'ixia',
    'ixl',
    'ixobrychus',
    'ixodes',
    'ixodid',
    'ixodidae',
    'iyar',
    'iyyar',
    'izanagi',
    'izanami',
    'izar',
    'izmir',
    'izzard']
